@@ -1,4 +1,4 @@
-pub(crate) use core::hash::Hash;
+use core::hash::Hash;
 use std::{
     fmt::Debug,
     marker::PhantomData,
@@ -77,6 +77,28 @@ where
         self.0 = cloned;
         Ok(())
     }
+
+    // Invariant must be upheld manually!
+    pub unsafe fn new_manual<V: Into<T>>(v: V) -> Self {
+        Self(v.into(), Default::default())
+    }
+
+    // Invariant must be upheld manually!
+    pub unsafe fn mutate_manual(&mut self, f: impl FnOnce(&mut T)) {
+        f(&mut self.0)
+    }
+
+    /// Gives mutable access to the internals without upholding invariants.
+    /// They must continue to be upheld manually while the reference lives!
+    pub unsafe fn get_mut(&mut self) -> &mut T {
+        &mut self.0
+    }
+
+    /// Verifies invariants. This is guaranteed to succeed unless you've used
+    /// one of the `unsafe` methods that require variants to be manually upheld.
+    pub fn verify(&self) -> Result<(), E> {
+        G::validate(&self.0).map_or(Ok(()), Err)
+    }
 }
 
 impl<G: Guard> Clone for Guarded<G>
